<?php
namespace Delo;

/**
 * Просто вспомогательный класс с функциями, чтобы не дублировать код
 * @package Delo
 */
class XmlReturn
{
    /**
     * Возвращает кусок xml с <result>
     * @param int $code 1 – Успех. Продолжить оплату. 2 – Неудача. Прервать процесс оплаты
     * @param string $desc описание ошибки или успеха
     * @return string xml
     */
    private function xmlResult($code, $desc)
    {
        return '<result><code>' . $code . '</code><desc><![CDATA[' . $desc . ']]></desc></result>';
    }

    /**
     * Возвращает отрицательный ответ на запрос проверки платежа от платежного шлюза
     * @param string $error причина неудачи
     * @return string xml
     */
    public function checkResponseFailed($error)
    {
        if (empty($error)) {
            $error = 'Unknown error';
        }
        return '<payment-avail-response>' . $this->xmlResult(2, $error) . '</payment-avail-response>';
    }

    /**
     * Возвращает положительный ответ на запрос проверки платежа от платежного шлюза
     * @param string $descResult Краткое описание результатов проверки. Не более 125 символов
     * @param string $descShortPurchase Краткое описание платежа. Не более 30 символов
     * @param string $descLongPurchase Полное описание платежа. Не более 125 символов. Это описание отображается клиенту на странице ввода реквизитов банковской карты
     * @param int $amount Сумма к оплате. В копейках
     * @return string xml
     */
    public function checkResponseSuccessful($descResult, $descShortPurchase, $descLongPurchase, $amount)
    {
        if (empty($descResult)) {
            $descResult = 'Краткое описание результатов проверки';
        }
        if (empty($descShortPurchase)) {
            $descShortPurchase = 'Краткое описание платежа';
        }
        if (empty($descLongPurchase)) {
            $descLongPurchase = 'Полное описание платежа';
        }
        $amount = (int)$amount;
        $currency = \Configuration::get(\DeloBank::PREFIX . 'currency', 0);
        // @todo: передавать информацию о покупателе доп. тегах - ФИО, телефон, email
        return '<payment-avail-response>' . $this->xmlResult(1, $descResult)
            . '<purchase>'
            . '<shortDesc><![CDATA[' . $descShortPurchase . ']]></shortDesc>'
            . '<longDesc><![CDATA[' . $descLongPurchase . ']]></longDesc>'
            . '<account-amount>'
            . '<amount>' . $amount . '</amount>'
            . '<currency>' . $currency . '</currency>'
            . '<exponent>2</exponent>'
            . '</account-amount>'
            . '</purchase>'
            . '</payment-avail-response>';
    }

    /**
     * Возвращает положительный ответ на запрос фиксации платежа от платежного шлюза
     * @param string $desc описание успешной регистрации платежа
     * @return string xml
     */
    public function registerResponseSuccessful($desc)
    {
        if (empty($desc)) {
            $desc = 'Платеж успешно зарегистрирован';
        }
        return '<register-payment-response>' . $this->xmlResult(1, $desc) . '</register-payment-response>';
    }

    /**
     * Возвращает отрицательный ответ на запрос фиксации платежа от платежного шлюза
     * @param string $error ошибка
     * @return string xml
     */
    public function registerResponseFailed($error)
    {
        if (empty($error)) {
            $error = 'Ошибка платежного шлюза';
        }
        return '<register-payment-response>' . $this->xmlResult(2, $error) . '</register-payment-response>';
    }
}
